import { HTMLAttributes, VNode } from "vue";
import { _TabelDataItem } from "./propTypes";
type align = "left" | "center" | "right";
export interface row {
    [key: string]: any;
}
interface renderParam<T> {
    row: T;
    column: TableComponent.Columns<T>;
    /**经过排序的下标 */
    index: number;
    indexs: Array<number>;
    /**原始数据下标 */
    dataIndex: number;
    dataIndexs: Array<number>;
    /**树形表格等级深度 */
    treeLever: number;
}
export declare namespace TableComponent {
    interface Columns<T> {
        /**列头名字 */
        title?: string;
        /**列字段 */
        key?: Extract<keyof T, string | number>;
        /**对齐方式*/
        align?: align;
        /**列宽 */
        width?: number;
        /**自定义渲染,类似vue的render函数 */
        render?: (param: renderParam<T>) => JSX.Element | string | number | VNode;
        /**自定义表头 */
        renderHeader?: (param: Pick<renderParam<T>, "column" | "index">) => JSX.Element | string | number | VNode;
        /**列class */
        className?: HTMLAttributes["class"];
        /**单元格class */
        cellClassName?: HTMLAttributes["class"];
        /**表头单元格class */
        cellHeaderClassName?: HTMLAttributes["class"];
        /**开启排序 */
        sortable?: boolean;
        /**表格类型 */
        type?: "" | "selection";
        /**是否为树形表格 */
        tree?: boolean;
    }
    type TabelDataItem<T = {}> = _TabelDataItem<T> & T;
}
type ExpandFunction = (param: {
    row: row;
    index: number;
}) => any;
export type ExpandRender = string | ExpandFunction;
export type SortType = "up" | "down" | "";
export interface SortConfig {
    /**排序类型*/
    type: SortType;
    /**排序的key */
    key: string;
    /**若没有key则使用index */
    columnIndex: number;
}
export interface TableEmitsLoad {
    ExportToExcel(): void;
    SetAllSelection(): void;
    ClearAllSelection(): void;
}
type GetTableRef = () => HTMLTableElement | undefined;
export interface TabelBodyEmitsLoadInput {
    GetTableRef: GetTableRef;
}
export interface TabelHeaderEmitsLoadInput {
    GetTableRef: GetTableRef;
}
export {};
